﻿## This file contains some of the options that can be changed to customize
## your Ren'Py game. It only contains the most common options... there
## is quite a bit more customization you can do.
##
## Lines beginning with two '#' marks are comments, and you shouldn't
## uncomment them. Lines beginning with a single '#' mark are
## commented-out code, and you may want to uncomment them when
## appropriate.
         
init -1 python hide:

    ## Should we enable the use of developer tools? This should be
    ## set to False before the game is released, so the user can't
    ## cheat using developer tools.

    config.developer = True

    ## These control the width and height of the screen.

    config.screen_width = 1024
    config.screen_height = 576

    ## This controls the title of the window, when Ren'Py is
    ## running in a window.

    config.window_title = u"Renpy Imagemap GUI Sample"

    #########################################
    # Layouts
    
    ## This enables the use of an in-game menu that is made out of
    ## buttons.

    layout.button_menu()

    #########################################
    # Themes
    
    ## We then want to call a theme function. themes.roundrect is
    ## a theme that features the use of rounded rectangles. It's
    ## the only theme we currently support.
    ##
    ## The theme function takes a number of parameters that can
    ## customize the color scheme.

    theme.roundrect(
        # Color scheme: Colorblind
                                    
        ## The color of an idle widget face.
        widget = "#898989",

        ## The color of a focused widget face.
        widget_hover = "#464646",

        ## The color of the text in a widget.
        widget_text = "#CCCCCC",

        ## The color of the text in a selected widget. (For
        ## example, the current value of a preference.)
        widget_selected = "#FFFFFF",
        #widget_selected = "#F2F2F2",

        ## The color of a disabled widget face. 
        disabled = "#898989",

        ## The color of disabled widget text.
        disabled_text = "#FFFFFF",

        ## The color of informational labels.
        label = "#c2c2c2",

        ## The color of a frame containing widgets.
        frame = "#252525",

        ## The background of the main menu. This can be a color
        ## beginning with '#', or an image filename. The latter
        ## should take up the full height and width of the screen.
        mm_root = "#393939",

        ## The background of the game menu. This can be a color
        ## beginning with '#', or an image filename. The latter
        ## should take up the full height and width of the screen.
        gm_root = "#393939",

        ## If this is True, the in-game window is rounded. If False,
        ## the in-game window is square.
        rounded_window = False,

        ## And we're done with the theme. The theme will customize
        ## various styles, so if we want to change them, we should
        ## do so below.            
        )


    #########################################
    ## These settings let you customize the window containing the
    ## dialogue and narration, by replacing it with an image.

    ## The background of the window. In a Frame, the two numbers
    ## are the size of the left/right and top/bottom borders,
    ## respectively.

    style.window.background = Frame("gui/frame.png", 0, 0)

    ## Margin is space surrounding the window, where the background
    ## is not drawn.

    # style.window.left_margin = 6
    # style.window.right_margin = 6
    # style.window.top_margin = 6
    # style.window.bottom_margin = 6

    ## Padding is space inside the window, where the background is
    ## drawn.

    style.window.left_padding = 60
    style.window.right_padding = 60
    style.window.top_padding = 10
    # style.window.bottom_padding = 6

    ## This is the minimum height of the window, including the margins
    ## and padding.

    # style.window.yminimum = 250


    #########################################
    ## This lets you change the placement of the main menu.

    ## The way placement works is that we find an anchor point
    ## inside a displayable, and a position (pos) point on the
    ## screen. We then place the displayable so the two points are
    ## at the same place.

    ## An anchor/pos can be given as an integer or a floating point
    ## number. If an integer, the number is interpreted as a number
    ## of pixels from the upper-left corner. If a floating point,
    ## the number is interpreted as a fraction of the size of the
    ## displayable or screen.

    # style.mm_menu_frame.xpos = 0.5
    # style.mm_menu_frame.xanchor = 0.5
    # style.mm_menu_frame.ypos = 0.75
    # style.mm_menu_frame.yanchor = 0.5


    #########################################
    ## These let you customize the default font used for text in Ren'Py.

    ## The file containing the default font.

    # style.default.font = "DejaVuSans.ttf"

    ## The default size of text.

    style.default.size = 24

    ## Note that these only change the size of some of the text. Other
    ## buttons have their own styles.
    #style.file_picker_ss_window.xpos = 248
    #style.file_picker_ss_window.ypos = 11

    #########################################
    ## These settings let you change some of the sounds that are used by
    ## Ren'Py.

    ## Set this to False if the game does not have any sound effects.

    config.has_sound = True

    ## Set this to False if the game does not have any music.

    config.has_music = True

    ## Set this to False if the game does not have voicing.

    config.has_voice = True

    ## Sounds that are used when button and imagemaps are clicked.

    # style.button.activate_sound = "click.wav"
    # style.imagemap.activate_sound = "click.wav"
    # style.imagemap.hover_sound = "sfx/tok.ogg"

    ## Sounds that are used when entering and exiting the game menu.

    # config.enter_sound = "click.wav"
    # config.exit_sound = "click.wav"

    ## A sample sound that can be played to check the sound volume.

    # config.sample_sound = "click.wav"

    ## Music that is played while the user is at the main menu.

    # config.main_menu_music = "main_menu_theme.ogg"

    
    #########################################
    ## Help.

    ## This lets you configure the help option on the Ren'Py menus.
    ## It may be:
    ## - A label in the script, in which case that label is called to
    ##   show help to the user.
    ## - A file name relative to the base directory, which is opened in a
    ##   web browser.
    ## - None, to disable help.   
    config.help = "None"


#██▓▒░ TRANSITIONS ░▒▓█████████████████████████████████████ 
# This block is responsible for transitions.

    ## Used when entering the game menu from the game.
    config.enter_transition = dissolve

    ## Used when exiting the game menu to the game.
    config.exit_transition = dissolve

    ## Used between screens of the game menu.
    config.intra_transition = dissolve

    ## Used when entering the game menu from the main menu.
    config.main_game_transition = dissolve

    ## Used when returning to the main menu from the game.
    config.game_main_transition = dissolve

    ## Used when entering the main menu from the splashscreen.
    config.end_splash_transition = dissolve

    ## Used when entering the main menu after the game has ended.
    config.end_game_transition = dissolve

    ## Used when a game is loaded.
    config.after_load_transition = dissolve

    ## Used when the window is shown.
    config.window_show_transition = dissolve

    ## Used when the window is hidden.
    config.window_hide_transition = dissolve


    #########################################
    ## This is the name of the directory where the game's data is
    ## stored. (It needs to be set early, before any other init code
    ## is run, so the persisten information can be found by the init code.)
python early:
    config.save_directory = "GUI Template Imagemap - PEACH-1283057230"

init -1 python hide:
    #########################################
    ## Default values of Preferences.

    ## Note: These options are only evaluated the first time a
    ## game is run. To have them run a second time, delete
    ## game/saves/persistent

    ## Should we start in fullscreen mode?

    config.default_fullscreen = False

    ## The default text speed in characters per second. 0 is infinite.

    config.default_text_cps = 60

    #########################################
    ## More customizations can go here.
    config.thumbnail_width = 167
    config.thumbnail_height = 94

    
#██▓▒░ TEXT DROP SHADOW ░▒▓█████████████████████████████████████ 
# This block is responsible for the text drop shadow.

init:
    $ style.default.drop_shadow = (2, 2)
    $ style.default.drop_shadow_color = "#000000"
    

#██▓▒░ IMAGEMAP MAIN MENU ░▒▓█████████████████████████████████████ 
#This block is responsible for the Imagemap based main menu
screen main_menu:
    tag menu
    if not persistent.extra_unlocked:
        imagemap:
            ground 'gui/imagemap_main_menu_idle.jpg'
            hover 'gui/imagemap_main_menu_hover.jpg'
        
            hotspot (773, 114, 191, 67) action Start() hovered [ Play ("test_one", "sfx/click.wav"), Show("gui_tooltip", my_picture="gui/tooltip_main_menu_start.png", my_tt_xpos=46, my_tt_ypos=518) ] unhovered [Hide("gui_tooltip")]
            hotspot (773, 210, 191, 67) action ShowMenu('load') hovered [ Play ("test_two", "sfx/click.wav"), Show("gui_tooltip", my_picture="gui/tooltip_main_menu_load.png", my_tt_xpos=46, my_tt_ypos=518) ] unhovered [Hide("gui_tooltip")]
            hotspot (773, 306, 191, 67) action ShowMenu('preferences') hovered [ Play ("test_three", "sfx/click.wav"), Show("gui_tooltip", my_picture="gui/tooltip_main_menu_config.png", my_tt_xpos=46, my_tt_ypos=518) ] unhovered [Hide("gui_tooltip")]
            hotspot (773, 402, 191, 67) action Quit(confirm=False) hovered [ Play ("test_four", "sfx/click.wav"), Show("gui_tooltip", my_picture="gui/tooltip_main_menu_quit.png", my_tt_xpos=46, my_tt_ypos=518) ] unhovered [Hide("gui_tooltip")]

    else:
        imagemap:
            ground 'gui/imagemap_main_menu_unlocked_idle.jpg'
            hover 'gui/imagemap_main_menu_unlocked_hover.jpg'
            hotspot (773, 114, 191, 67) action Start() hovered [ Play ("test_one", "sfx/click.wav"), Show("gui_tooltip", my_picture="gui/tooltip_main_menu_start.png", my_tt_xpos=46, my_tt_ypos=518) ] unhovered [Hide("gui_tooltip")]
            hotspot (773, 185, 191, 67) action ShowMenu('load') hovered [ Play ("test_two", "sfx/click.wav"), Show("gui_tooltip", my_picture="gui/tooltip_main_menu_load.png", my_tt_xpos=46, my_tt_ypos=518) ] unhovered [Hide("gui_tooltip")]
            hotspot (773, 256, 191, 67) action ShowMenu('preferences') hovered [ Play ("test_three", "sfx/click.wav"), Show("gui_tooltip", my_picture="gui/tooltip_main_menu_config.png", my_tt_xpos=46, my_tt_ypos=518) ] unhovered [Hide("gui_tooltip")]
            hotspot (773, 327, 191, 67) action Start('extras') hovered [ Play ("test_four", "sfx/click.wav"), Show("gui_tooltip", my_picture="gui/tooltip_main_menu_extra.png", my_tt_xpos=46, my_tt_ypos=518) ] unhovered [Hide("gui_tooltip")]
            hotspot (773, 398, 191, 67) action Quit(confirm=False) hovered [ Play ("test_five", "sfx/click.wav"), Show("gui_tooltip", my_picture="gui/tooltip_main_menu_quit.png", my_tt_xpos=46, my_tt_ypos=518) ] unhovered [Hide("gui_tooltip")]

#██▓▒░ IMAGEMAP PREFERENCES ░▒▓███████████████████████████████████ 
#This block is responsible for the Imagemap based main menu

screen preferences:
    tag menu
    
    imagemap:
        ground 'gui/imagemap_config_ground.jpg'
        idle 'gui/imagemap_config_idle.png'
        hover 'gui/imagemap_config_hover.png'
        selected_idle 'gui/imagemap_config_selected_idle.png'
        selected_hover 'gui/imagemap_config_selected_hover.png'

        hotspot (315, 201, 78, 78) action Preference('display', 'window') hovered [ Play ("test_one", "sfx/click.wav"), Show("gui_tooltip", my_picture="gui/tooltip_config_windowed.png", my_tt_xpos=46, my_tt_ypos=518) ] unhovered [Hide("gui_tooltip")]
        hotspot (403, 201, 78, 78) action Preference('display', 'fullscreen') hovered [ Play ("test_two", "sfx/click.wav"), Show("gui_tooltip", my_picture="gui/tooltip_config_fullscreen.png", my_tt_xpos=46, my_tt_ypos=518) ] unhovered [Hide("gui_tooltip")]
        hotspot (517, 201, 78, 78) action Preference('transitions', 'none') hovered [ Play ("test_three", "sfx/click.wav"), Show("gui_tooltip", my_picture="gui/tooltip_config_disable_transition.png", my_tt_xpos=46, my_tt_ypos=518) ] unhovered [Hide("gui_tooltip")]
        hotspot (606, 201, 78, 78) action Preference('transitions', 'all') hovered [ Play ("test_four", "sfx/click.wav"), Show("gui_tooltip", my_picture="gui/tooltip_config_enable_transition.png", my_tt_xpos=46, my_tt_ypos=518) ] unhovered [Hide("gui_tooltip")]
        
        hotspot (-1, -1, -1, -1) action Preference('joystick') hover_sound "sfx/tok.ogg"
        
        hotspot (315, 360, 78, 78) action Preference('after choices', 'stop') hovered [ Play ("test_one", "sfx/click.wav"), Show("gui_tooltip", my_picture="gui/tooltip_config_stop_skip.png", my_tt_xpos=46, my_tt_ypos=518) ] unhovered [Hide("gui_tooltip")]
        hotspot (403, 360, 78, 78) action Preference('after choices', 'skip') hovered [ Play ("test_two", "sfx/click.wav"), Show("gui_tooltip", my_picture="gui/tooltip_config_go_skip.png", my_tt_xpos=46, my_tt_ypos=518) ] unhovered [Hide("gui_tooltip")]
        hotspot (517, 360, 78, 78) action Preference('skip', 'seen') hovered [ Play ("test_three", "sfx/click.wav"), Show("gui_tooltip", my_picture="gui/tooltip_config_seen.png", my_tt_xpos=46, my_tt_ypos=518) ] unhovered [Hide("gui_tooltip")]
        hotspot (606, 360, 78, 78) action Preference('skip', 'all') hovered [ Play ("test_four", "sfx/click.wav"), Show("gui_tooltip", my_picture="gui/tooltip_config_all.png", my_tt_xpos=46, my_tt_ypos=518) ] unhovered [Hide("gui_tooltip")]
        
        hotspot (420, 117, 151, 22) action Preference('begin skipping') hovered [ Play ("test_one", "sfx/click.wav"), Show("gui_tooltip", my_picture="gui/tooltip_config_skipping.png", my_tt_xpos=46, my_tt_ypos=518) ] unhovered [Hide("gui_tooltip")]
        
        hotbar (57, 136, 217, 36) value Preference('music volume') 
        hotbar (57, 202, 217, 36) value Preference('sound volume') 
        hotbar (57, 268, 217, 36) value Preference('voice volume') 
        hotbar (57, 354, 217, 36) value Preference('text speed')
        hotbar (57, 420, 217, 36) value Preference('auto-forward time') 
        
        hotspot (790, 99, 233, 56) action ShowMenu('save') hovered [ Play ("test_one", "sfx/click.wav"), Show("gui_tooltip", my_picture="gui/tooltip_geme_menu_save.png", my_tt_xpos=46, my_tt_ypos=518) ] unhovered [Hide("gui_tooltip")]
        hotspot (790, 164, 233, 56) action ShowMenu('load') hovered [ Play ("test_two", "sfx/click.wav"), Show("gui_tooltip", my_picture="gui/tooltip_geme_menu_load.png", my_tt_xpos=46, my_tt_ypos=518) ] unhovered [Hide("gui_tooltip")]
        hotspot (790, 227, 233, 56) action ShowMenu('preferences') hovered [ Play ("test_three", "sfx/click.wav"), Show("gui_tooltip", my_picture="gui/tooltip_geme_menu_config.png", my_tt_xpos=46, my_tt_ypos=518) ] unhovered [Hide("gui_tooltip")]
        hotspot (790, 291, 233, 56) action MainMenu() hovered [ Play ("test_one", "sfx/click.wav"), Show("gui_tooltip", my_picture="gui/tooltip_geme_menu_main.png", my_tt_xpos=46, my_tt_ypos=518) ] unhovered [Hide("gui_tooltip")]
        hotspot (790, 355, 233, 56) action Return() hovered [ Play ("test_two", "sfx/click.wav"), Show("gui_tooltip", my_picture="gui/tooltip_geme_menu_return.png", my_tt_xpos=46, my_tt_ypos=518) ] unhovered [Hide("gui_tooltip")]
        hotspot (790, 419, 233, 56) action Quit() hovered [ Play ("test_three", "sfx/click.wav"), Show("gui_tooltip", my_picture="gui/tooltip_geme_menu_quit.png", my_tt_xpos=46, my_tt_ypos=518) ] unhovered [Hide("gui_tooltip")]
        
        


#██▓▒░ IMAGEMAP SAVE / LOAD SCREEN ░▒▓███████████████████████████████████ 
#This block is responsible for the Imagemap based main menu
# This represents a load/save slot. You should customize this to ensure
# that the placement of the thumbnail and the slot text are as desired.
# All positions are relative to the hotspot the slot is inside.

# This represents a load/save slot. You should customize this to ensure
# that the placement of the thumbnail and the slot text are as desired.
# All positions are relative to the hotspot the slot is inside.

screen load_save_slot:
    $ file_text = "% s\n  %s" % (FileTime(number, empty="Empty Slot."), FileSaveName(number))
    add FileScreenshot(number) xpos 321 ypos 10
    text file_text xpos 10 ypos 11 size 20
 
screen load:
    
    tag menu
    
    imagemap:
        ground 'gui/imagemap_load_ground.jpg'
        idle 'gui/imagemap_load_idle.png'
        hover 'gui/imagemap_load_hover.png'
        selected_idle 'gui/imagemap_load_selected_idle.png'
        selected_hover 'gui/imagemap_load_selected_hover.png'

        hotspot (-1, -1, -1, -1) action FilePage('auto')
        hotspot (46, 104, 127, 115) action FilePage(1) hover_sound "sfx/click.wav"
        hotspot (46, 228, 127, 115) action FilePage(2) hover_sound "sfx/click.wav"
        hotspot (46, 353, 127, 115) action FilePage(3) hover_sound "sfx/click.wav"

        hotspot (195, 104, 498, 115) action FileAction(0): 
            use load_save_slot(number=0) 
        hotspot (195, 228, 498, 115) action FileAction(1):
            use load_save_slot(number=1)
        hotspot (195, 353, 498, 115) action FileAction(2):
            use load_save_slot(number=2)

        hotspot (790, 99, 233, 56) action ShowMenu('save') hovered [ Play ("test_one", "sfx/click.wav"), Show("gui_tooltip", my_picture="gui/tooltip_geme_menu_save.png", my_tt_xpos=46, my_tt_ypos=518) ] unhovered [Hide("gui_tooltip")]
        hotspot (790, 164, 233, 56) action ShowMenu('load') hovered [ Play ("test_two", "sfx/click.wav"), Show("gui_tooltip", my_picture="gui/tooltip_geme_menu_load.png", my_tt_xpos=46, my_tt_ypos=518) ] unhovered [Hide("gui_tooltip")]
        hotspot (790, 227, 233, 56) action ShowMenu('preferences') hovered [ Play ("test_three", "sfx/click.wav"), Show("gui_tooltip", my_picture="gui/tooltip_geme_menu_config.png", my_tt_xpos=46, my_tt_ypos=518) ] unhovered [Hide("gui_tooltip")]
        hotspot (790, 291, 233, 56) action MainMenu() hovered [ Play ("test_one", "sfx/click.wav"), Show("gui_tooltip", my_picture="gui/tooltip_geme_menu_main.png", my_tt_xpos=46, my_tt_ypos=518) ] unhovered [Hide("gui_tooltip")]
        hotspot (790, 355, 233, 56) action Return() hovered [ Play ("test_two", "sfx/click.wav"), Show("gui_tooltip", my_picture="gui/tooltip_geme_menu_return.png", my_tt_xpos=46, my_tt_ypos=518) ] unhovered [Hide("gui_tooltip")]
        hotspot (790, 419, 233, 56) action Quit() hovered [ Play ("test_three", "sfx/click.wav"), Show("gui_tooltip", my_picture="gui/tooltip_geme_menu_quit.png", my_tt_xpos=46, my_tt_ypos=518) ] unhovered [Hide("gui_tooltip")]
        
screen save:
    
    tag menu
    
    imagemap:
        ground 'gui/imagemap_save_ground.jpg'
        idle 'gui/imagemap_save_idle.png'
        hover 'gui/imagemap_save_hover.png'
        selected_idle 'gui/imagemap_save_selected_idle.png'
        selected_hover 'gui/imagemap_save_selected_hover.png'
 
        hotspot (-1, -1, -1, -1) action FilePage('auto')
        hotspot (46, 104, 127, 115) action FilePage(1) hover_sound "sfx/click.wav"
        hotspot (46, 228, 127, 115) action FilePage(2) hover_sound "sfx/click.wav"
        hotspot (46, 353, 127, 115) action FilePage(3) hover_sound "sfx/click.wav"

        
        hotspot (195, 104, 498, 115) action FileAction(0): 
            use load_save_slot(number=0) 
        hotspot (195, 228, 498, 115) action FileAction(1):
            use load_save_slot(number=1)
        hotspot (195, 353, 498, 115) action FileAction(2):
            use load_save_slot(number=2)

        hotspot (790, 99, 233, 56) action ShowMenu('save') hovered [ Play ("test_one", "sfx/click.wav"), Show("gui_tooltip", my_picture="gui/tooltip_geme_menu_save.png", my_tt_xpos=46, my_tt_ypos=518) ] unhovered [Hide("gui_tooltip")]
        hotspot (790, 164, 233, 56) action ShowMenu('load') hovered [ Play ("test_two", "sfx/click.wav"), Show("gui_tooltip", my_picture="gui/tooltip_geme_menu_load.png", my_tt_xpos=46, my_tt_ypos=518) ] unhovered [Hide("gui_tooltip")]
        hotspot (790, 227, 233, 56) action ShowMenu('preferences') hovered [ Play ("test_three", "sfx/click.wav"), Show("gui_tooltip", my_picture="gui/tooltip_geme_menu_config.png", my_tt_xpos=46, my_tt_ypos=518) ] unhovered [Hide("gui_tooltip")]
        hotspot (790, 291, 233, 56) action MainMenu() hovered [ Play ("test_one", "sfx/click.wav"), Show("gui_tooltip", my_picture="gui/tooltip_geme_menu_main.png", my_tt_xpos=46, my_tt_ypos=518) ] unhovered [Hide("gui_tooltip")]
        hotspot (790, 355, 233, 56) action Return() hovered [ Play ("test_two", "sfx/click.wav"), Show("gui_tooltip", my_picture="gui/tooltip_geme_menu_return.png", my_tt_xpos=46, my_tt_ypos=518) ] unhovered [Hide("gui_tooltip")]
        hotspot (790, 419, 233, 56) action Quit() hovered [ Play ("test_three", "sfx/click.wav"), Show("gui_tooltip", my_picture="gui/tooltip_geme_menu_quit.png", my_tt_xpos=46, my_tt_ypos=518) ] unhovered [Hide("gui_tooltip")]

        
#██▓▒░ IMAGEMAP YES/NO PROMPT ░▒▓███████████████████████████████████ 
#This block is responsible for the Imagemap based yes / no prompt
# You'll need to edit this to change the position and style of the text.

screen yesno_prompt:
    on "show" action Play("sound", "sfx/alert.wav")
    
    modal True

    imagemap:
        ground 'gui/yesno_ground.png'
        idle 'gui/yesno_idle.png'
        hover 'gui/yesno_hover.png'
        
        hotspot (267, 369, 231, 72) action yes_action hover_sound "sfx/click.wav"
        hotspot (526, 369, 231, 72) action no_action hover_sound "sfx/click.wav"

    if message == layout.ARE_YOU_SURE:
        add "gui/yesno_are_you_sure.png"
    elif message == layout.DELETE_SAVE:
        add "gui/yesno_delete_save.png"
    elif message == layout.OVERWRITE_SAVE:
        add "gui/yesno_overwrite_save.png"
    elif message == layout.LOADING:
        add "gui/yesno_loading.png"
    elif message == layout.QUIT:
        add "gui/yesno_quit.png"
    elif message == layout.MAIN_MENU:
        add "gui/yesno_main_menu.png"

        
#██▓▒░ CUSTOM MOUSE POINTER ░▒▓███████████████████████████████████ 
#This block is responsible for the 
#CustomMouse Pointer

init python:
    config.mouse = { }
    config.mouse["default"] = [
         ("gui/mouse_pointer.png", 8.8, 0.0),
    ]

    
#██▓▒░ TOOLTIP  ░▒▓████████████████████████████████████████████  
#This block declares the Tooltip

screen gui_tooltip:
    add my_picture xpos my_tt_xpos ypos my_tt_ypos
    
    
#██▓▒░ CUSTOM SOUND CHANNEL  ░▒▓███████████████████████████████████ 
# This is the block where we declare the individual sound channels 
# that enables us to play several sound FX's without overlapping

init python:
    renpy.music.register_channel("test_one", "sfx", False)
    renpy.music.register_channel("test_two", "sfx", False)
    renpy.music.register_channel("test_three", "sfx", False)
    renpy.music.register_channel("test_four", "sfx", False)
    renpy.music.register_channel("test_five", "sfx", False)
    renpy.music.register_channel("test_six", "sfx", False)
